summaryrefslogtreecommitdiff
path: root/src/portable/st/stm32_fsdev/fsdev_common.h
diff options
context:
space:
mode:
authorZixun LI <[email protected]>2025-11-27 11:02:49 +0100
committerZixun LI <[email protected]>2025-11-27 11:02:49 +0100
commit5d56828e43ef5f894c4586e7e7a61c3fbbbbfaf9 (patch)
tree5958bb77e91e576f375b6c99ffcbe84031832e51 /src/portable/st/stm32_fsdev/fsdev_common.h
parent270e1492764959c278f1b154b8e42aef4dcd98d8 (diff)
extract core reset
Signed-off-by: Zixun LI <[email protected]>
Diffstat (limited to 'src/portable/st/stm32_fsdev/fsdev_common.h')
-rw-r--r--src/portable/st/stm32_fsdev/fsdev_common.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/portable/st/stm32_fsdev/fsdev_common.h b/src/portable/st/stm32_fsdev/fsdev_common.h
index e363245ec..9cf61031d 100644
--- a/src/portable/st/stm32_fsdev/fsdev_common.h
+++ b/src/portable/st/stm32_fsdev/fsdev_common.h
@@ -311,9 +311,13 @@ TU_ATTR_ALWAYS_INLINE static inline void btable_set_count(uint32_t ep_id, uint8_
#endif
}
-/* Aligned buffer size according to hardware */
+// Reset the USB Core
+void fsdev_core_reset(void);
+
+// Aligned buffer size according to hardware
uint16_t pma_align_buffer_size(uint16_t size, uint8_t* blsize, uint8_t* num_block);
+// Set RX buffer size
void btable_set_rx_bufsize(uint32_t ep_id, uint8_t buf_id, uint16_t wCount);
//--------------------------------------------------------------------+